@@ -6,7 +6,7 @@
 #![feature(const_raw_ptr_deref)]
 
 use components_arena::{Arena, Component, NewtypeComponentId, Id};
-use dep_obj::{DepObjBaseBuilder, dep_obj, dep_type, dep_type_with_builder};
+use dep_obj::{DepObjBaseBuilder, DepObjId, dep_obj, dep_type, dep_type_with_builder};
 use macro_attr_2018::macro_attr;
 use dep_obj::binding::{Bindings, Binding1, Binding2};
 use dyn_context::state::{State, StateExt};
@@ -26,6 +26,8 @@ macro_attr! {
     struct Item(Id<ItemData>);
 }
 
+impl DepObjId for Item { }
+
 dep_type_with_builder! {
     #[derive(Debug)]
     struct ItemProps become props in Item {
@@ -99,6 +101,8 @@ macro_attr! {
     struct Npc(Id<NpcComponent>);
 }
 
+impl DepObjId for Npc { }
+
 dep_type! {
     #[derive(Debug)]
     struct NpcProps in Npc {
